-- Create a single set of %install tasks for a known kind of Go subpackage
local function singleinstall(kind, suffix, verbose)
  local go = require "fedora.srpm.go"
  local gorpm = require "fedora.rpm.go"
  if     (kind == "devel")  then
    go.develenv(suffix, verbose)
    for goipath in string.gmatch(rpm.expand("%{currentgoipaths}"), "[^%s]+") do
      gorpm.env('', goipath, verbose, {})
      local vflag = verbose and " -v" or ""
      print(rpm.expand("%__godevelinstall -i " .. goipath .. vflag .. "\n"))
    end
    print(rpm.expand("%__godevelinstalldoc\n"))
  elseif (kind == "alt") then
    local fedora = require "fedora.common"
    local ismain = (suffix == "") or (suffix == "0")
    if ismain then
      fedora.zalias({"goaltipaths","gocid","goaltcid"},                verbose)
    end
    fedora.safeset("goaltcid" .. suffix, "%{?gocid"  .. suffix .. "}", verbose)
    if ismain then
      fedora.zalias({"goaltcid"},                                      verbose)
    end
    for rpmname, goaltipaths in pairs(go.indexedgoipaths("%{goaltipaths" .. suffix .. "}",
                                                         "%{goaltcid"    .. suffix .. "}")) do
      go.altenv(suffix, rpmname, goaltipaths, verbose)
      gocanonipath = rpm.expand("%{currentgocanonipath}")
      for _, goaltipath in ipairs(goaltipaths) do
        fedora.explicitset("currentgoaltipath", goaltipath)
        print(rpm.expand("%__goaltinstall\n"))
        goaltipath = string.gsub(goaltipath, "/?[^/]+/?$", "")
        while (not string.match(gocanonipath, "^" .. goaltipath)) do
          print(rpm.expand('echo \'%dir "%{gopath}/src/' .. goaltipath .. '"\' >> "%{goworkdir}/%{currentgoaltfilelist}"\n'))
          goaltipath  = string.gsub(goaltipath, "/?[^/]+/?$", "")
        end
      end
    end
  else
    rpm.expand("%{error:Unknown kind of Go subpackage: " .. kind .. "}")
  end
end

-- Create one or all %install tasks for a known kind of go subpackage
local function install(kind, suffix, processall, verbose)
  local fedora = require "fedora.common"
  local go     = require "fedora.srpm.go"
  if (kind == "devel") then
    go.develenvinit()
  end
  if processall then
    for _, suffix in pairs(fedora.getsuffixes(go.pivot[kind])) do
       singleinstall(kind, suffix, verbose)
    end
  else
    singleinstall(kind, suffix, verbose)
  end
end

return {
  install = install,
}
