-- Create a single %package section for a known kind of Go subpackage
local function singlepkg(kind, suffix, verbose)
  local fedora = require "fedora.common"
  local go     = require "fedora.srpm.go"
  if     (kind == "devel")  then
    go.develenv(suffix, verbose)
    print(
      rpm.expand(
        "%package     -n %{currentgodevelname}\n" ..
        "Summary:        %{currentgodevelsummary}\n" ..
        "BuildRequires:  go-rpm-macros\n" ..
        "BuildArch:      noarch\n" ..
        "%{?currentgodevelheader}\n" ..
        "%description -n %{currentgodevelname}\n") ..
      fedora.wordwrap("%{?currentgodeveldescription}") ..
      "\n")
  elseif (kind == "alt") then
    local ismain = (suffix == "") or (suffix == "0")
    if ismain then
      fedora.zalias({"goaltipaths","gocid","goaltcid"},                verbose)
    end
    fedora.safeset("goaltcid" .. suffix, "%{?gocid"  .. suffix .. "}", verbose)
    if ismain then
      fedora.zalias({"goaltcid"},                                      verbose)
    end
    for rpmname, goaltipaths in pairs(go.indexedgoipaths("%{goaltipaths" .. suffix .. "}",
                                                      "%{goaltcid"    .. suffix .. "}")) do
      go.altenv(suffix, rpmname, goaltipaths, verbose)
      print(
        rpm.expand(
          "%package     -n %{currentgoaltname}\n" ..
          "Summary:        %{currentgoaltsummary}\n" ..
          "BuildRequires:  go-rpm-macros\n" ..
          "BuildArch:      noarch\n" ..
          "%{?currentgoaltheader}\n" ..
          "%description -n %{currentgoaltname}\n") ..
        fedora.wordwrap("%{?currentgoaltdescription}") ..
        "\n")
    end
  else
    rpm.expand("%{error:Unknown kind of Go subpackage: " .. kind .. "}")
  end
end

-- Create one or all %package sections for a known kind of go subpackage
local function pkg(kind, suffix, processall, verbose)
  local fedora = require "fedora.common"
  local go     = require "fedora.srpm.go"
  if (kind == "devel") then
    go.develenvinit()
  end
  if processall then
    for _, suffix in pairs(fedora.getsuffixes(go.pivot[kind])) do
       singlepkg(kind, suffix, verbose)
    end
  else
    singlepkg(kind, suffix, verbose)
  end
end

-- Create a single %files section for a known kind of Go subpackage
local function singlefiles(kind, suffix, verbose)
  local go     = require "fedora.srpm.go"
  if     (kind == "devel")  then
    go.develenv(suffix, verbose)
    print(rpm.expand('%files -n %{currentgodevelname}    -f "%{goworkdir}/%{currentgodevelfilelist}"\n'))
  elseif (kind == "alt") then
    local fedora = require "fedora.common"
    local ismain = (suffix == "") or (suffix == "0")
    if ismain then
      fedora.zalias({"goaltipaths","gocid","goaltcid"},                verbose)
    end
    fedora.safeset("goaltcid" .. suffix, "%{?gocid"  .. suffix .. "}", verbose)
    if ismain then
      fedora.zalias({"goaltcid"},                                      verbose)
    end
    for rpmname, goaltipaths in pairs(go.indexedgoipaths("%{goaltipaths" .. suffix .. "}",
                                                      "%{goaltcid"    .. suffix .. "}")) do
      go.altenv(suffix, rpmname, goaltipaths, verbose)
      print(rpm.expand('%files -n %{currentgoaltname} -f "%{goworkdir}/%{currentgoaltfilelist}"\n'))
    end
  else
    rpm.expand("%{error:Unknown kind of Go subpackage: " .. kind .. "}")
  end
end

-- Create one or all %files sections for a known kind of go subpackage
local function files(kind, suffix, processall, verbose)
  local fedora = require "fedora.common"
  local go     = require "fedora.srpm.go"
  if (kind == "devel") then
    go.develenvinit()
  end
  if processall then
    for _, suffix in pairs(fedora.getsuffixes(go.pivot[kind])) do
       singlefiles(kind, suffix, verbose)
    end
  else
    singlefiles(kind, suffix, verbose)
  end
end

return {
  pkg             = pkg,
  files           = files,
 }
